package controller.listener;

import java.awt.event.MouseEvent;
import java.util.ArrayList;
import javax.swing.event.MouseInputAdapter;
import controller.DrawableObjectProcessing;
import model.drawables.BezierCurve;
import model.drawables.Circle;
import model.drawables.Point;

/**
 * Ein Listener, der Bezierkurven durch MouseEvents erzeugt.
 * 
 * @author Denis Meyer
 * @author Niels Meyering
 */
public class BezierCurveListener extends MouseInputAdapter {

	protected ArrayList<Point> tmpPoints;
	private DrawableObjectProcessing delegate;
	private Point lastPoint;

	/**
	 * @param delegate
	 */
	public BezierCurveListener(DrawableObjectProcessing delegate) {
		tmpPoints = new ArrayList<Point>();
		this.delegate = delegate;
	}

	/**
	 * Füge den aktuellen Punkt als Point in die Punktliste ein.
	 * 
	 * @param e
	 */
	public void mouseClicked(MouseEvent e) {

		if (tmpPoints.isEmpty())
			tmpPoints.add(new Point(e.getX(), e.getY()));
		else {
			if (tmpPoints.size() == 3) {
				tmpPoints.add(new Point(e.getX(), e.getY()));
				for (Point p : tmpPoints) {
					delegate.processDrawableObject(new Circle(p, 3));
				}
				delegate.processDrawableObject(new BezierCurve(tmpPoints, 3));
				lastPoint = tmpPoints.get(tmpPoints.size() - 1);
				tmpPoints.clear();
				tmpPoints.add(lastPoint);
			} else {
				tmpPoints.add(new Point(e.getX(), e.getY()));
			}
		}
		System.out.println(tmpPoints.size()
				+ ". Sttzpunkt erfolgreich hinzugefgt!");

	}

	/**
	 * Setze den Status des Listeners zurück.
	 * 
	 * @param e
	 */
	public void mouseExited(MouseEvent e) {
		// Leere aktuelle Liste
		tmpPoints.clear();
	}
}
