package controller.listener;

import java.awt.event.MouseEvent;

import javax.swing.event.MouseInputAdapter;

import model.drawables.DashedRectangle;
import model.drawables.Point;
import model.drawables.Rectangle;
import controller.DrawableObjectProcessing;

/**
 * Erzeugt mit MouseEvents ein ClippingRectangle und übergibt dieses dem
 * Delegate zur weiteren Verarbeitung.
 * 
 * @author Nicolas Neubauer
 * 
 */
public class ClippingRectangleListener extends MouseInputAdapter {

	private Point tmp;
	private DrawableObjectProcessing delegate;

	/**
	 * @param delegate
	 */
	public ClippingRectangleListener(DrawableObjectProcessing delegate) {
		this.delegate = delegate;
	}

	/**
	 * Merke die aktuelle Koordinate des Startpunktes oder, sofern schon
	 * vorhanden, erzeuge mit Hilfe des neuen (End-)punkts ein neues Rectangle
	 * und übergebe es dem Delegate.
	 * 
	 * @param e
	 */
	public void mouseClicked(MouseEvent e) {

		if (tmp == null)
			tmp = new Point(e.getX(), e.getY());
		else {

			// Lösche temporäres Object
			delegate.clearTemporaryDrawableObject();

			Rectangle r = new Rectangle(tmp, new Point(e.getX(), e.getY()));
			tmp = null;

			delegate.clipDrawableObjects(r);
		}

	}

	/**
	 * Übergebe mit Hilfe der aktuellen Mausposition ein DashedRectangle als
	 * temporäres Objekt an das Delegate.
	 * 
	 * @param e
	 */
	public void mouseMoved(MouseEvent e) {
		if (tmp != null) {
			DashedRectangle r = new DashedRectangle(tmp, new Point(e.getX(), e
					.getY()));
			// Temporäres Objekt neu zeichnen
			delegate.setTemporaryDrawableObject(r);
		}
	}

}
