/**
 * 
 */
package controller.listener;

import java.awt.event.MouseEvent;

import javax.swing.event.MouseInputAdapter;

import controller.DrawableObjectProcessing;

import model.drawables.DashedLine;
import model.drawables.Line;
import model.drawables.Point;

/**
 * Ein Listener, der Lines durch MouseEvents erzeugt und an ein Objekt, das
 * DrawableObjectProcessing implementiert übergibt.
 * 
 * @author Nicolas Neubauer
 * 
 */
public class LineListener extends MouseInputAdapter {

	private Point tmp;
	private DrawableObjectProcessing delegate;

	/**
	 * @param delegate
	 */
	public LineListener(DrawableObjectProcessing delegate) {
		this.delegate = delegate;
	}

	/**
	 * Merke die aktuelle Koordinate des Startpunktes oder, sofern schon
	 * vorhanden, erzeuge mit Hilfe des neuen (End-)punkts eine neue Line und
	 * übergebe sie dem Delegate.
	 * 
	 * @param e
	 */
	public void mouseClicked(MouseEvent e) {

		if (tmp == null)
			tmp = new Point(e.getX(), e.getY());
		else {

			// Lösche temporäres Object
			delegate.clearTemporaryDrawableObject();

			Line l = new Line(tmp, new Point(e.getX(), e.getY()));
			tmp = null;
			delegate.processDrawableObject(l);

		}

	}

	/**
	 * Übergebe mit Hilfe der aktuellen Mausposition eine DashedLine als
	 * temporäres Objekt an das Delegate, sofern bereits ein Mittelpunkt
	 * vorliegt.
	 * 
	 * @param e
	 */
	public void mouseMoved(MouseEvent e) {
		if (tmp != null) {
			DashedLine l = new DashedLine(tmp, new Point(e.getX(), e.getY()));
			// Temporäres Objekt neu zeichnen
			delegate.setTemporaryDrawableObject(l);
		}
	}

}
