package controller.listener;

import java.awt.event.MouseEvent;
import java.util.LinkedList;
import java.util.List;

import javax.swing.event.MouseInputAdapter;

import controller.DrawableObjectProcessing;

import model.drawables.DashedPolygon;
import model.drawables.Point;
import model.drawables.Polygon;

/**
 * Ein Listener, der Polygone durch MouseEvents erzeugt.
 * 
 * @author Nicolas Neubauer
 * 
 */
public class PolygonListener extends MouseInputAdapter {

	protected List<Point> tmpPoints;
	private DrawableObjectProcessing delegate;

	/**
	 * @param delegate
	 */
	public PolygonListener(DrawableObjectProcessing delegate) {
		tmpPoints = new LinkedList<Point>();
		this.delegate = delegate;
	}

	/**
	 * Füge den aktuellen Punkt als Point in die Punktliste ein.
	 * 
	 * @param e
	 */
	public void mouseClicked(MouseEvent e) {

		if (tmpPoints.size() == 0)
			tmpPoints.add(new Point(e.getX(), e.getY()));
		else {

			int maxEntfernung = 5;
			// Prüfen ob fertig
			if (tmpPoints.size() > 2
					&& Math.abs(tmpPoints.get(0).x - e.getX()) <= maxEntfernung
					&& Math.abs(tmpPoints.get(0).y - e.getY()) <= maxEntfernung) {
				// Lösche temporäres Object
				delegate.clearTemporaryDrawableObject();
				// Fertig, also Polygon erzeugen und übergeben
				delegate.processDrawableObject(createPolygon());
				tmpPoints = new LinkedList<Point>();
			} else {
				// Nicht fertig, ist der neue Punkt weit genug weg?
				if (Math.abs(tmpPoints.get(0).x - e.getX()) > maxEntfernung
						|| Math.abs(tmpPoints.get(0).y - e.getY()) > maxEntfernung) {
					// Ja, also Punkt hinzufügen
					tmpPoints.add(new Point(e.getX(), e.getY()));
				}
				// Ansonsten, tue einfach nichts
			}

		}

	}

	/**
	 * Erzeugt ein ungefülltes Polygon und gibt dieses zurück
	 * 
	 * @return ungefülltes Polygon-Objekt
	 */
	protected Polygon createPolygon() {
		return new Polygon(tmpPoints, false);
	}

	/**
	 * Übergebe mit Hilfe der aktuellen Mausposition ein DashedPolygon als
	 * temporäres Objekt an das Delegate.
	 * 
	 * @param e
	 */
	public void mouseMoved(MouseEvent e) {
		if (tmpPoints.size() > 0) {
			DashedPolygon p = new DashedPolygon(tmpPoints, new Point(e.getX(),
					e.getY()));
			// Temporäres Objekt neu zeichnen
			delegate.setTemporaryDrawableObject(p);
		}
	}

	/**
	 * Setze den Status des Listeners zurück.
	 * 
	 * @param e
	 */
	public void mouseExited(MouseEvent e) {
		// Lösche temporäres Object
		delegate.clearTemporaryDrawableObject();
		// Erzeuge neue Liste
		tmpPoints = new LinkedList<Point>();
	}

}
